@@ -3,7 +3,10 @@
   sd.scalar <- function (x, ...) {sqrt(var(as.vector(x), ...))}
   wmean <- function (x, w, ...) {mean(x*w, ...)/mean(w, ...)}
   logit <- function (x) {log(x/(1-x))}
-  untriangle <- function (x) {x + t(x) - x*diag(nrow(as.matrix(x)))}
+  .untriangle <- function (x) {x + t(x) - x*diag(nrow(as.matrix(x)))}
+
+
+
 
 # new functions! 
 
